@@ -47,9 +47,10 @@
 #endif /* WSM */
 #include "WmWinInfo.h"
 #include "WmWinState.h"
+#include "WmXmP.h"
 
 #include <Xm/RowColumnP.h> /* for MS_LastManagedMenuTime */
-extern XmMenuState _XmGetMenuState();
+
 
 #ifdef WSM
 /*
@@ -1199,12 +1200,9 @@ Boolean HandleKeyPress (XKeyEvent *keyEvent,
 		{
 		  processKey = False;
 		}
-
-	      if ((keySpecs->wmFunction == F_Menu) ||
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-		  (keySpecs->wmFunction == F_Post_RMenu) ||
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-		  (keySpecs->wmFunction == F_Post_SMenu))
+		
+		if ((keySpecs->wmFunction == F_Menu) ||
+		(keySpecs->wmFunction == F_Post_SMenu))
 		{
 		  wmGD.menuUnpostKeySpec = keySpecs;  /* menu unpost key spec */
 		}
@@ -1223,7 +1221,7 @@ Boolean HandleKeyPress (XKeyEvent *keyEvent,
 		}
 #endif /* ROOT_ICON_MENU */
 	      if (!(keySpecs->wmFunction (keySpecs->wmFuncArgs,
-					  functionClient, keyEvent)))
+					  functionClient, (XEvent*)keyEvent)))
 		{
 		  /*
 		   * The window manager function return indicates that further
@@ -1515,7 +1513,7 @@ Boolean CheckForButtonAction (XButtonEvent *buttonEvent, Context context, Contex
 		}
 
 	        if (!(buttonSpec->wmFunction (buttonSpec->wmFuncArgs, pCD,
-					      buttonEvent)))
+					      (XEvent*)buttonEvent)))
 		{
 		    /*
 		     * The window manager function return indicates that
@@ -2555,39 +2553,6 @@ Time GetTimestamp (void)
 
 } /* END OF FUNCTION GetTimestamp */
 
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-/*************************************<->*************************************
- *
- *  LastTime ()
- *
- *
- *  Description:
- *  -----------
- *  This function is used to provide a timestamp for use with X calls that
- *  require a timestamp. It returns the last timestamp processed if one
- *  exists or it generates a new one.
- *
- *
- *  Inputs:
- *  ------
- *  none
- * 
- *  Outputs:
- *  -------
- *  Return = a timestamp value - NOT CurrentTime
- *
- *************************************<->***********************************/
-
-Time LastTime ()
-{
-  Time evTime;
-
-  if (! (evTime = XtLastTimestampProcessed(DISPLAY)) )
-    evTime = GetTimestamp();
-
-  return (evTime);
-}
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
 
 
 /*************************************<->*************************************
