@@ -51,6 +51,11 @@
 /*
  * Value definitions and macros:
  */
+/* Version info */
+#define MWM_NAME "EMWM"
+#define MWM_VERSION  1
+#define MWM_REVISION 3
+#define MWM_UPDATE 1
 
 /* window manager name and class used to get resources: */
 #define	WM_RESOURCE_CLASS	"Emwm"
@@ -88,13 +93,6 @@ extern Pixel		FPselectcolor;
 #endif /* WSM */
 
 /* ICCC atom names: */
-
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-# define _XA_TARGETS		"TARGETS"
-# define _XA_MULTIPLE		"MULTIPLE"
-# define _XA_TIMESTAMP		"TIMESTAMP"
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
 #define _XA_WM_STATE		"WM_STATE"
 #define _XA_WM_PROTOCOLS	"WM_PROTOCOLS"
 #define _XA_WM_CHANGE_STATE	"WM_CHANGE_STATE"
@@ -103,27 +101,6 @@ extern Pixel		FPselectcolor;
 #define _XA_WM_TAKE_FOCUS	"WM_TAKE_FOCUS"
 #define _XA_WM_COLORMAP_WINDOWS	"WM_COLORMAP_WINDOWS"
 
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-/* original set of query targets */
-# define _XA_MOTIF_WM_CLIENT_WINDOW		"_MOTIF_WM_CLIENT_WINDOW"
-# define _XA_MOTIF_WM_POINTER_WINDOW		"_MOTIF_WM_POINTER_WINDOW"
-# define _XA_MOTIF_WM_ALL_CLIENTS		"_MOTIF_WM_ALL_CLIENTS"
-	  
-/* menu command interface support */
-# define _XA_MOTIF_WM_DEFINE_COMMAND		"_MOTIF_WM_DEFINE_COMMAND"
-# define _XA_MOTIF_WM_INCLUDE_COMMAND		"_MOTIF_WM_INCLUDE_COMMAND"
-# define _XA_MOTIF_WM_REMOVE_COMMAND		"_MOTIF_WM_REMOVE_COMMAND"
-# define _XA_MOTIF_WM_ENABLE_COMMAND		"_MOTIF_WM_ENABLE_COMMAND"
-# define _XA_MOTIF_WM_DISABLE_COMMAND		"_MOTIF_WM_DISABLE_COMMAND"
-# define _XA_MOTIF_WM_RENAME_COMMAND		"_MOTIF_WM_RENAME_COMMAND"
-# define _XA_MOTIF_WM_INVOKE_COMMAND		"_MOTIF_WM_INVOKE_COMMAND"
-# define _XA_MOTIF_WM_REQUEST_COMMAND		"_MOTIF_WM_REQUEST_COMMAND"
-# define _XA_MOTIF_WM_WINDOW_FLAGS		"_MOTIF_WM_WINDOW_FLAGS"
-
-/* automation support */
-# define _XA_MOTIF_WM_AUTOMATION 		"_MOTIF_WM_AUTOMATION"
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
 /* window manager exit value on fatal errors: */
 #define WM_ERROR_EXIT_VALUE	1
 
@@ -406,12 +383,13 @@ typedef Atom WorkspaceID;
  *  window manager functions (e.g., set the colormap focus).
  *
  *************************************<->***********************************/
-
 typedef unsigned long Context;
 typedef unsigned long Behavior;
 typedef unsigned long GroupArg;
 
-typedef Boolean (*WmFunction) ();
+typedef struct _ClientData ClientData;
+
+typedef Boolean (*WmFunction) (String, ClientData*, XEvent*);
 
 #define NO_MODIFIER	0		/* value for state field */
 
@@ -733,20 +711,6 @@ typedef struct _SessionGeom
  *
  *************************************<->***********************************/
 
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-/*
- * Used to denote where the separators belong in a pair of separators
- * used to surround a client command.
- */
-
-enum { TOP_SEPARATOR, BOTTOM_SEPARATOR };
-
-/*
- * Used to denote what kind of change to make to a client command. 
- */
-typedef enum { ENABLE, DISABLE, REMOVE, RENAME } CmdModifier;
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
 typedef struct _MenuItem
 {
     int		 labelType;
@@ -760,11 +724,6 @@ typedef struct _MenuItem
     String	 wmFuncArgs;
     Context	 greyedContext;
     long         mgtMask;
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-    String       clientCommandName; /* as specified by the user in
-				       his .mwmrc file. */
-    CARD32	 clientCommandID;
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
     struct _MenuItem *nextMenuItem;
 
 } MenuItem;
@@ -790,14 +749,6 @@ typedef struct _MenuButton
 
 } MenuButton;
 
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-typedef struct _MenuExclusion
-{
-  String                 command_string;
-  struct _MenuExclusion *nextExclusion;
-} MenuExclusion;
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
 typedef struct _MenuSpec
 {
     String	  name;
@@ -812,49 +763,11 @@ typedef struct _MenuSpec
     unsigned int  menuButtonCount; /* number of menuButtons elements in use */
     Context	  accelContext;    /* accelerator context */
     KeySpec	 *accelKeySpecs;   /* list of accelerator KeySpecs */
-
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-    MenuExclusion *exclusions;      /* list of client commands to be
-				       excluded from this menu. */
-    Boolean        clientLocal;     /* this menu is owned by a client and not 
-				       shared with any other clients */
-    CARD32         commandID;       /* if this is a client command, then this
-				       its id value - globally unique. */
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
     struct _MenuSpec *nextMenuSpec;
 
 } MenuSpec;
 
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-/* The range to which a client command operation should apply. */
-typedef enum { SINGLE, ROOT, ALL } OpRange;
 
-typedef struct _CmdTree {
-  CARD32           commandID;   /* unique identifier for this command. */
-  CARD32           notifyWindow;/* window to receive InvokeCommand request. */
-  char            *name;        /* name of command refered to in .mwmrc. */
-  char            *defaultName; /* default label of menu. */
-  struct _CmdTree *subTrees;    /* list of child commands or command sets. */
-  struct _CmdTree *next;
-
-} CmdTree;
-
-
-typedef struct _matchlist {
-    MenuSpec          *menuspec;
-    MenuItem          *menuitem;
-    String             command_string;
-    CmdTree           *treenode;
-    WmFunction         function;
-    String             funcargs;
-    Context            greyed_context;
-    struct _matchlist *next;
-
-} MatchList;
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
-
 /*************************************<->*************************************
  *
  *  Window and function specification data structures ...
@@ -1206,9 +1119,6 @@ typedef struct _WmScreenData
     Window	rootWindow;
     Widget	screenTopLevelW;
     Widget	screenTopLevelW1;       /* for internal WM components */
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-    Widget	utmShell;		/* DrawingArea used for UTM */
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
     Widget      confirmboxW[4];
 #ifdef WSM
     WsPresenceData	presence;	/* workspace presence dialog*/
@@ -1236,9 +1146,6 @@ typedef struct _WmScreenData
 #ifdef WSM
     struct _WmWorkspaceData	*pLastWS;	/* previously active WS */
 #endif /* WSM */
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-    CmdTree     *cciTree;               /* pointer to cci definitions */
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
 
     /* per screen caches */
     BitmapCache *bitmapCache;
@@ -1286,9 +1193,9 @@ typedef struct _WmScreenData
     int     actionNbr;
 
     /* resource description file data: */
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
+#ifndef WSM
     String	rootMenu;			/* resource */
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
+#endif /* WSM */
     String	buttonBindings;			/* resource */
     ButtonSpec	*buttonSpecs;
     String	keyBindings;			/* resource */
@@ -1823,12 +1730,6 @@ typedef struct _ClientData *PtrClientData;
 #define UNSEEN_STATE            8
 #endif /* WSM */
 
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-# define NO_CHANGE              -1
-# define UNSET                   0
-# define SET                     1
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
 /* clientFlags field values: */
 #define CLIENT_HINTS_TITLE		(1L << 0)
 #define CLIENT_REPARENTED		(1L << 1)
@@ -2055,34 +1956,6 @@ typedef struct _WmGlobalData
     Atom	xa_MWM_INFO;
     Atom	xa_MWM_OFFSET;
     Atom	xa_MWM_CLIENT_LIST;
-
-#if ((!defined(WSM)) || defined(MWM_QATS_PROTOCOL))
-    Atom       *xa_WM;
-
-    Atom	xa_TARGETS;
-    Atom	xa_MULTIPLE;
-    Atom	xa_TIMESTAMP;
-
-    /* original set of query targets */
-    Atom	_MOTIF_WM_CLIENT_WINDOW;
-    Atom	_MOTIF_WM_POINTER_WINDOW;
-    Atom	_MOTIF_WM_ALL_CLIENTS	;
-	  
-    /* menu command interface support */
-    Atom	_MOTIF_WM_DEFINE_COMMAND;
-    Atom	_MOTIF_WM_INCLUDE_COMMAND;
-    Atom	_MOTIF_WM_REMOVE_COMMAND;
-    Atom	_MOTIF_WM_ENABLE_COMMAND;
-    Atom	_MOTIF_WM_DISABLE_COMMAND;
-    Atom	_MOTIF_WM_RENAME_COMMAND;
-    Atom	_MOTIF_WM_INVOKE_COMMAND;
-    Atom	_MOTIF_WM_REQUEST_COMMAND;
-    Atom	_MOTIF_WM_WINDOW_FLAGS;
-
-    /* automation support */
-    Atom        _MOTIF_WM_AUTOMATION;
-#endif /* !defined(WSM) || defined(MWM_QATS_PROTOCOL) */
-
     Atom	xa_MOTIF_BINDINGS;
     Atom	xa_COMPOUND_TEXT;
     Atom	xa_SM_CLIENT_ID;
@@ -2393,3 +2266,5 @@ extern char *_DtGetMessage(char *filename, int set, int n, char *s);
     string
 #endif
 #endif /* _WmGlobal_h */
+
+void PrintVersionInfo(void);
