@@ -1653,10 +1653,7 @@ void SetGranularity (WmWorkspaceData *pWS, ClientData *pCD, IconBoxData *pIBD)
  * 
  *************************************<->***********************************/
 
-MenuItem *GetIconBoxMenuItems (pSD)
-
-    WmScreenData *pSD;
-
+MenuItem *GetIconBoxMenuItems (WmScreenData *pSD)
 {
 
     return(ParseMwmMenuStr (pSD, 
@@ -1979,12 +1976,8 @@ Boolean InsertIconIntoBox (IconBoxData *pIBD, ClientData *pCD)
  * 
  *************************************<->***********************************/
 
-IconInfo *InsertIconInfo (pIBD, pCD, theWidget)
-
-    IconBoxData *pIBD;
-    ClientData *pCD;
-    Widget theWidget;
-
+IconInfo *InsertIconInfo (IconBoxData *pIBD,
+	ClientData *pCD, Widget theWidget)
 {
     IconInfo *pII;
     int place;
