@@ -886,9 +886,7 @@ int GetBitmapIndex (WmScreenData *pSD, char *name)
  * 
  *************************************<->***********************************/
 
-char *BitmapPathName (string)
-    char *string;
-
+char *BitmapPathName(char *string)
 {
     static char  fileName[MAXWMPATH+1];
     char *retname;
